# pywib

Pywib (Python Web Interaction Behaviour) is a library desgined for analysing and obtaning metrics from users interaction with web pages.

## How to
```python
from pywib import velocity, velocity_metrics

v = velocity(df_all_sessions)
v_metrics = velocity_metrics(None, v)
```

## Running the tests
First, navigate to the pywib folder
```bash
cd pywib
```

Then install the required dependencies using python, use a virtual environment if you wish to.
```python
pip install pytest
pip install -r requirements.txt
```
Then, run the tests using:
```python
pytest test
```

## Generating Documentation
```
cd pywib/docs
make html
```
